export interface IAgentInstanceInfo {
    agentId: string;
    technology: string;
    agentType: AgentType;
    agentVersion: string;
    buildSessionId?: string;
    uniqueModuleId?: string;
    labId?: string;
    agentConfig: IMap;
    tags: ITagInfo[];
    processId: number;
    processArch: string;
    processSessionId?: number;
    argv: string[];
    cwd: string;
    envVars: IMap;
    tools: IToolInfo[];
    sendsPing: boolean;
}
export interface IMachineInfo {
    machineName?: string;
    arch?: string;
    os: string;
    localDateTime: string;
    localDateTimeUnix_s: number;
    runtime: string;
    ipAddress: string[];
}
export interface ITechSpecificInfo {
}
export interface INodeJsEnvInfo {
    nodeVersion: string;
    indexJsonDeps?: IMap;
}
export interface IBrowserEnvInfo {
    userAgent: string;
    location: string;
}
export interface ITagInfo {
    name: string;
    version: string;
}
export interface IToolInfo {
    name: string;
    version: string;
}
export interface IMap {
    [key: string]: any;
}
export interface IPingData {
    avgCpuLoad: number;
    freeRam_KB: number;
}
export interface IAgentCiInfo {
    jobName: string;
    jobId: string;
    jobUrl: string;
}
export declare enum AgentType {
    BUILD_SCANNER = "BuildScanner",
    TEST_LISTENER = "TestListener",
    PRODUCTION_LISTENER = "ProductionListener",
    BROWSER_AGENT = "BrowserAgent",
    SLNODEJS = "slnodejs"
}
export interface IAgentStartInfo {
    agentInfo: IAgentInstanceInfo;
    machineInfo: IMachineInfo;
    techSpecificInfo: ITechSpecificInfo;
    pingData?: IPingData;
    ciInfo: IAgentCiInfo;
}
export interface IInfoBuilder<T> {
    fillData(): void;
    build(): T;
}
export declare enum AgentEventCode {
    AGENT_STARTED = 1001,
    AGENT_SHUTDOWN = 1002,
    AGENT_PING = 1003,
    GENERIC_MESSAGE = 2000,
    WARN = 3000
}
export interface IAgentEvent<T> {
    type: AgentEventCode;
    utcTimestamp_ms: number;
    data?: T;
}
export interface IAgentEventRequest<T> {
    agentId: string;
    events: IAgentEvent<T>[];
    appName?: string;
    buildSessionId?: string;
}
export declare enum Technology {
    NODEJS = "nodejs",
    BROWSER = "browser"
}
