"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var SEALIGHTS_ENV_VAR_PREFIX = "SL_";
var AgentInstanceInfoBuilder = /** @class */ (function () {
    function AgentInstanceInfoBuilder(agentEventsController) {
        this.agentConfig = agentEventsController.agentConfig;
        this.agentId = agentEventsController.agentInstanceData.agentId;
        this.agentType = agentEventsController.agentInstanceData.agentType;
        this.tags = agentEventsController.resolveTags();
        this.tools = agentEventsController.tools;
        this.sendsPing = agentEventsController.sendsPing;
        this.logger = agentEventsController.logger;
        this.technology = agentEventsController.agentInstanceData.technology;
        this.info = {
            agentId: agentEventsController.agentInstanceData.agentId,
            agentType: agentEventsController.agentInstanceData.agentType,
            agentVersion: agentEventsController.agentInstanceData.agentVersion,
            technology: agentEventsController.agentInstanceData.technology
        };
    }
    AgentInstanceInfoBuilder.prototype.fillData = function () {
        this.info.tags = this.tags;
        this.info.tools = this.tools;
        this.info.technology = this.technology;
        this.info.sendsPing = this.sendsPing;
        this.fillFromAgentConfig();
        this.fillFromProcessObject();
    };
    AgentInstanceInfoBuilder.prototype.build = function () {
        this.fillData();
        return this.info;
    };
    AgentInstanceInfoBuilder.prototype.fillFromAgentConfig = function () {
        this.info.buildSessionId = this.agentConfig.buildSessionId.value;
        this.info.labId = this.agentConfig.labId.value;
        this.info.agentConfig = this.agentConfig.toJsonObject();
    };
    ;
    AgentInstanceInfoBuilder.prototype.fillFromProcessObject = function () {
        this.info.processId = process.pid;
        this.info.processArch = process.arch;
        this.info.argv = process.argv;
        this.info.cwd = process.cwd();
        this.info.envVars = this.extractSealightsEnvVars();
    };
    ;
    AgentInstanceInfoBuilder.prototype.extractSealightsEnvVars = function () {
        var slEnvVars = {};
        Object.keys(process.env).forEach(function (key) {
            if (key.indexOf(SEALIGHTS_ENV_VAR_PREFIX) === 0) {
                slEnvVars[key] = process.env[key];
            }
        });
        return slEnvVars;
    };
    AgentInstanceInfoBuilder.DEFAULT_BROWSER_AGENT_VERSION = "1.0.0";
    AgentInstanceInfoBuilder.SEALIGHTS_WINDOW_OBJECT = "$Sealights";
    return AgentInstanceInfoBuilder;
}());
exports.AgentInstanceInfoBuilder = AgentInstanceInfoBuilder;
//# sourceMappingURL=agent-instance-info-builder.js.map