"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var os = require("os");
var system_date_1 = require("../system-date");
var MachineInfoBuilder = /** @class */ (function () {
    function MachineInfoBuilder() {
        this.info = {};
    }
    MachineInfoBuilder.prototype.fillData = function () {
        var currentDate = new Date(system_date_1.getSystemDateValueOf());
        this.info.machineName = os.hostname();
        this.info.arch = os.arch();
        this.info.os = os.platform();
        this.info.localDateTime = currentDate.toString();
        this.info.localDateTimeUnix_s = currentDate.getTime();
        this.info.runtime = process.version;
        this.info.ipAddress = this.extractIpAddresses();
    };
    MachineInfoBuilder.prototype.build = function () {
        this.fillData();
        return this.info;
    };
    MachineInfoBuilder.prototype.extractIpAddresses = function () {
        var ipAddresses = [];
        var interfaces = os.networkInterfaces();
        Object.keys(interfaces).forEach(function (key) {
            var addressesArr = interfaces[key];
            ipAddresses = ipAddresses.concat(addressesArr.map(function (addressObject) { return addressObject.address; }));
        });
        return ipAddresses;
    };
    return MachineInfoBuilder;
}());
exports.MachineInfoBuilder = MachineInfoBuilder;
//# sourceMappingURL=machine-info-builder.js.map