"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var uuid = require("uuid");
var agent_events_conracts_1 = require("./agent-events/agent-events-conracts");
var files_utils_1 = require("./utils/files-utils");
var fs_1 = require("fs");
var agent_instance_info_builder_1 = require("./agent-events/agent-instance-info-builder");
var AgentInstanceData = /** @class */ (function () {
    function AgentInstanceData(agentType, technology) {
        this.agentType = agentType;
        this.technology = technology;
        this.agentId = uuid();
        this.agentVersion = this.resolveAgentVersion();
    }
    AgentInstanceData.prototype.resolveAgentVersion = function () {
        if (this.technology === agent_events_conracts_1.Technology.BROWSER) {
            return this.resolveAgentVersionForBrowserAgent();
        }
        var packageJsonFilePath = files_utils_1.FilesUtils.findFileUp("package.json", __dirname);
        if (packageJsonFilePath) {
            try {
                var packageJson = fs_1.readFileSync(packageJsonFilePath).toString();
                var parsed = JSON.parse(packageJson);
                return parsed.version;
            }
            catch (e) {
                console.warn("Failed to resolve agent version, Error: '" + e);
                return null;
            }
        }
        return null;
    };
    AgentInstanceData.prototype.resolveAgentVersionForBrowserAgent = function () {
        return (window && window[agent_instance_info_builder_1.AgentInstanceInfoBuilder.SEALIGHTS_WINDOW_OBJECT] && window[agent_instance_info_builder_1.AgentInstanceInfoBuilder.SEALIGHTS_WINDOW_OBJECT].agentVersion) || agent_instance_info_builder_1.AgentInstanceInfoBuilder.DEFAULT_BROWSER_AGENT_VERSION;
    };
    return AgentInstanceData;
}());
exports.AgentInstanceData = AgentInstanceData;
//# sourceMappingURL=agent-instance-data.js.map