"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
var validation_utils_1 = require("../utils/validation-utils");
var system_date_1 = require("../system-date");
var EventsProcess = /** @class */ (function () {
    function EventsProcess(configuration, agentInstanceData, sendToServerWatchdog, keepAliveWatchdog, environmentDataService, backendProxy, eventsQueue, logger) {
        this._isRunning = false;
        this.sequence = 0;
        this._onGoingRequests = [];
        validation_utils_1.ValidationUtils.verifyNotNullOrEmpty(configuration, "configuration");
        validation_utils_1.ValidationUtils.verifyNotNullOrEmpty(agentInstanceData, "agentInstanceData");
        validation_utils_1.ValidationUtils.verifyNotNullOrEmpty(sendToServerWatchdog, "sendToServerWatchdog");
        validation_utils_1.ValidationUtils.verifyNotNullOrEmpty(keepAliveWatchdog, "keepAliveWatchdog");
        validation_utils_1.ValidationUtils.verifyNotNullOrEmpty(environmentDataService, "environmentData");
        validation_utils_1.ValidationUtils.verifyNotNullOrEmpty(backendProxy, "backendProxy");
        validation_utils_1.ValidationUtils.verifyNotNullOrEmpty(eventsQueue, "eventsQueue");
        validation_utils_1.ValidationUtils.verifyNotNullOrEmpty(logger, "logger");
        this._configuration = configuration;
        this._agentInstanceData = agentInstanceData;
        this._sendToServerWatchdog = sendToServerWatchdog;
        this.keepAliveWatchdog = keepAliveWatchdog;
        this.environmentData = environmentDataService;
        this._backendProxy = backendProxy;
        this._logger = logger;
        this._eventsQueue = eventsQueue;
        this.init();
    }
    EventsProcess.prototype.enqueueEvent = function (evt) {
        evt.localTime = evt.localTime || system_date_1.getSystemDateValueOf();
        this._eventsQueue.enqueue(evt);
        if (this.isRunning && this.configuration.sendEvents.value && this.configuration.enabled.value) {
            this.ensureKeepaliveThreadRunning();
        }
    };
    EventsProcess.prototype.start = function () {
        if (this._isRunning || !this._configuration.enabled.value) {
            return;
        }
        this._sendToServerWatchdog.start();
        if (this._eventsQueue.getQueueSize() > 0) {
            this.ensureKeepaliveThreadRunning();
        }
        this._isRunning = true;
    };
    EventsProcess.prototype.stop = function () {
        return __awaiter(this, void 0, void 0, function () {
            var e_1;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        this._sendToServerWatchdog.stop();
                        this.keepAliveWatchdog.stop();
                        if (this._configuration.enabled.value === false || this._configuration.sendEvents.value === false) { //Events/Agent functionality is disabled. Return immediately
                            return [2 /*return*/];
                        }
                        _a.label = 1;
                    case 1:
                        _a.trys.push([1, 4, , 5]);
                        return [4 /*yield*/, Promise.all(this._onGoingRequests)];
                    case 2:
                        _a.sent();
                        return [4 /*yield*/, this.submitEventsSync()];
                    case 3:
                        _a.sent();
                        return [3 /*break*/, 5];
                    case 4:
                        e_1 = _a.sent();
                        this._logger.warn("Error while stopping EventsProcess: ", e_1);
                        return [3 /*break*/, 5];
                    case 5:
                        this._isRunning = false;
                        return [2 /*return*/];
                }
            });
        });
    };
    EventsProcess.prototype.getQueueSize = function () {
        return this._eventsQueue.getQueueSize();
    };
    EventsProcess.prototype.submitEvents = function () {
        var _this = this;
        if (!this._isRunning ||
            !this._configuration.sendEvents.value ||
            !this._configuration.enabled.value ||
            this._eventsQueue.getQueueSize() == 0) {
            return;
        }
        var items = this._eventsQueue.dequeue(EventsProcess.ITEMS_TO_DEQUE);
        var packet = this.createEventsPacket(items);
        var promise = this._backendProxy.submitEventsPromise(packet);
        this._onGoingRequests.push(promise);
        promise.then(function () {
            if (_this._eventsQueue.getQueueSize() > 0) {
                _this.submitEvents();
            }
            _this.removeRequest(promise);
        });
        promise.catch(function (err) {
            _this._logger.warn("Error while submitting events, " + err);
            _this._eventsQueue.requeue(items);
            _this.removeRequest(promise);
        });
    };
    EventsProcess.prototype.submitEventsSync = function () {
        return __awaiter(this, void 0, void 0, function () {
            var items, packet, e_2;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        _a.trys.push([0, 4, , 5]);
                        _a.label = 1;
                    case 1:
                        if (!(this._eventsQueue.getQueueSize() > 0)) return [3 /*break*/, 3];
                        items = this._eventsQueue.dequeue(EventsProcess.ITEMS_TO_DEQUE);
                        packet = this.createEventsPacket(items);
                        return [4 /*yield*/, this._backendProxy.submitEventsPromise(packet)];
                    case 2:
                        _a.sent();
                        return [3 /*break*/, 1];
                    case 3: return [3 /*break*/, 5];
                    case 4:
                        e_2 = _a.sent();
                        this._logger.warn("Error while sending events synchronously. " + e_2);
                        return [3 /*break*/, 5];
                    case 5: return [2 /*return*/];
                }
            });
        });
    };
    EventsProcess.prototype.createEventsPacket = function (items) {
        return {
            customerId: this._configuration.customerId.value,
            appName: this._configuration.appName.value,
            build: this._configuration.build.value,
            branch: this._configuration.branch.value,
            environment: this.environmentData,
            configurationData: this._configuration.toJsonObject,
            testSelectionStatus: this._testSelectionStatus,
            events: items,
            meta: {
                sequence: ++this.sequence,
                generated: system_date_1.getSystemDateValueOf(),
                agentId: this._agentInstanceData.agentId,
            },
        };
    };
    EventsProcess.prototype.init = function () {
        var _this = this;
        this._sendToServerWatchdog.on("alarm", function () { return _this.submitEvents(); });
        this._eventsQueue.on("full", function () { return _this.submitEvents(); });
        this.keepAliveWatchdog.on("alarm", function () {
            if (_this.eventsQueue.getQueueSize() == 0) {
                _this.keepAliveWatchdog.stop();
            }
        });
    };
    EventsProcess.prototype.ensureKeepaliveThreadRunning = function () {
        this.keepAliveWatchdog.start();
    };
    EventsProcess.prototype.removeRequest = function (request) {
        var index = this._onGoingRequests.indexOf(request);
        this._onGoingRequests.splice(index, 1);
    };
    Object.defineProperty(EventsProcess.prototype, "onGoingRequests", {
        get: function () {
            return this._onGoingRequests;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(EventsProcess.prototype, "configuration", {
        get: function () {
            return this._configuration;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(EventsProcess.prototype, "logger", {
        get: function () {
            return this._logger;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(EventsProcess.prototype, "isRunning", {
        get: function () {
            return this._isRunning;
        },
        set: function (value) {
            this._isRunning = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(EventsProcess.prototype, "sendToServerWatchdog", {
        get: function () {
            return this._sendToServerWatchdog;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(EventsProcess.prototype, "backendProxy", {
        get: function () {
            return this._backendProxy;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(EventsProcess.prototype, "eventsQueue", {
        get: function () {
            return this._eventsQueue;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(EventsProcess.prototype, "testSelectionStatus", {
        get: function () {
            return this._testSelectionStatus;
        },
        set: function (testSelectionStatus) {
            this._testSelectionStatus = testSelectionStatus;
        },
        enumerable: true,
        configurable: true
    });
    EventsProcess.ITEMS_TO_DEQUE = 1000;
    return EventsProcess;
}());
exports.EventsProcess = EventsProcess;
//# sourceMappingURL=index.js.map