import { HttpClientConfigData, BuildSessionData, CreateBuildSessionIdResponse, GetVersionRequest, BuildMappingRequest, GetRemoteConfigRequest, SubmitLogsRequest, StartExecutionRequest, EndExecutionRequest, AgentData, UploadReportsBody, IHttpClient, ITestsRecommendationResponse, IBuildEndData } from "./contracts";
import bunyan = require('bunyan');
import { IEventsFile } from "../events-process/events-contracts";
import { IAgentEventRequest } from "../agent-events/agent-events-conracts";
import { AgentInstanceData } from "../agent-instance-data";
import { IIntegrationBuildDependency } from "../contracts";
export declare class BackendProxy {
    static readonly DEFAULT_HTTP_MAX_ATTEMPTS = 6;
    static readonly DEFAULT_HTTP_ATTEMPT_INTERVAL: number;
    protected config: HttpClientConfigData;
    private client;
    protected logger: bunyan;
    protected agentInstanceData: AgentInstanceData;
    constructor(agentInstanceData: AgentInstanceData, config: HttpClientConfigData, logger: bunyan, httpClient?: IHttpClient);
    getBuildSession(buildSessionId: string, callback: (err: Error, response: BuildSessionData) => void): void;
    createBuildSessionId(request: BuildSessionData, callback: (err: Error, response: CreateBuildSessionIdResponse) => void): void;
    createBuildSessionIdPromise<T extends BuildSessionData>(request: T): Promise<string>;
    getRecommendedVersion(request: GetVersionRequest): Promise<any>;
    submitBuildMapping(request: BuildMappingRequest): Promise<any>;
    submitLogs(request: SubmitLogsRequest, callback: (err: Error, body: any) => void): void;
    getRemoteConfig(request: GetRemoteConfigRequest, callback: (err: Error, body: any) => void): void;
    startExecution(request: StartExecutionRequest, callback: (err: Error, body: any) => void): void;
    uploadReport(request: UploadReportsBody | AgentData, callback: (err: Error, body: any) => void): void;
    externalReport(request: UploadReportsBody | AgentData, callback: (err: Error, body: any) => void): void;
    endExecution(request: EndExecutionRequest, callback: (err: Error, body: any) => void): void;
    submitEvents(packetToSend: IEventsFile, callback: (err: Error, body: any) => void, async?: boolean): void;
    submitEventsPromise(packetToSend: IEventsFile): Promise<void>;
    submitBlob(body: string, buildSessionId: string, blobId: string, callback: (err: Error, body: any) => void): void;
    submitAgentEvent<T>(body: IAgentEventRequest<T>): Promise<void>;
    getTestsRecommendation(buildSessionId: string, stage: string): Promise<ITestsRecommendationResponse>;
    addOrUpdateIntegrationBuildComponents(buildSessionId: string, components: IIntegrationBuildDependency[], agentId: string): Promise<unknown>;
    deleteIntegrationBuildComponents(buildSessionId: string, components: IIntegrationBuildDependency[], agentId: string): Promise<unknown>;
    buildEnd(data: IBuildEndData): Promise<void>;
    protected invokeCallback(callback: (err: Error, apiResponse: any) => void, err: Error, body: any, map?: (body: any) => any): void;
    private submitPostRequestWithRetries;
    private submitPutRequestWithRetries;
    private submitDelRequestWithRetries;
    private submitGetRequestWithRetries;
    private makeRequestWithRetries;
    private shouldRetryRequest;
}
