export declare class HttpClientConfigData {
    token: string;
    proxy: string;
    server: string;
    compressRequests?: boolean;
}
export interface BuildSessionData {
    appName: string;
    buildName: string;
    branchName: string;
    buildSessionId: string;
    additionalArguments?: string;
}
export declare class CreateBuildSessionIdResponse {
    buildSessionId: string;
}
export interface IPullRequestParams {
    repositoryUrl: string;
    pullRequestNumber: number;
    latestCommit: string;
    targetBranch: string;
}
export interface IPRConfigRequest extends BuildSessionData {
    pullRequestParams: IPullRequestParams;
}
export declare class GetVersionRequest {
    customerId: string;
    appName: string;
    testStage: string;
    branchName: string;
    componentName: string;
    buildName: string;
}
export declare class GetVersionResponse {
    agent: AgentInfo;
    meta: VersionMeta;
}
export declare class AgentInfo {
    date: number;
    name: string;
    url: string;
    version: string;
}
export declare class VersionMeta {
    generated: number;
    requestUrl: string;
    query: VersionMetaQuery;
}
export declare class VersionMetaQuery {
    agentType: string;
    isDefault: boolean;
}
export declare class BuildMappingRequest {
    meta: any;
    files: Array<FileData>;
    dependencies: Array<DependencyData>;
}
export declare class DependencyData {
    appName: string;
    branch: string;
    build: string;
}
export declare class FileData {
    logicalPath: string;
    physicalPath: string;
    methods: Array<any>;
    lines: Array<any>;
    hash: string;
}
export declare class GetRemoteConfigRequest {
    appName?: string;
    branch?: string;
    build?: string;
    testStage?: string;
    labId?: string;
}
export declare class SubmitLogsRequest {
    appName: string;
    customerId: string;
    testStage: string;
    log: string;
    creationTime: number;
}
export declare class BaseRequest {
    customerId: string;
    appName: string;
    server: string;
    proxy: string;
    isValidToken: boolean;
}
export declare class StartExecutionRequest extends BaseRequest {
    testStage: string;
    source?: string;
    labId: string;
    buildName: string;
    branchName: string;
    newEnvironment: string;
    environment: string;
}
export declare class EndExecutionRequest extends BaseRequest {
    environment: string;
    buildName: string;
    branchName: string;
}
export declare class UploadReportRequest extends BaseRequest {
    environmentName: string;
    reportFile: Array<string>;
    reportFilesFolder: Array<string>;
    labId: string;
    build: string;
    branch: string;
    source: string;
    type: string;
    hasMoreRequests: boolean;
}
export declare class AgentData {
    customerId: string;
    appName: string;
    type: string;
    source: string;
    hasMoreRequests: boolean;
    buildName?: string;
    branchName?: string;
    environment: EnvironmentData;
}
export declare class EnvironmentData {
    labId: string;
    environmentName: string;
}
export declare class UploadReportsBody {
    agentData: AgentData;
    reportFile: any;
}
export interface IHttpClient {
    get<T>(urlPath: string, callback: (err: Error, response: T, statusCode: number) => void, isNotFoundAcceptable?: boolean): any;
    delete<T>(body: any, urlPath: string, callback: (err: Error, data: T, statusCode: number) => void): any;
    put(requestData: any, urlPath: string, callback: (err: Error, body: any, statusCode: number) => void, async?: boolean, contentType?: string): any;
    post(requestData: any, urlPath: string, callback: (err: Error, body: any, statusCode: number) => void, async?: boolean, contentType?: string): any;
    postMultipart(requestData: any, urlPath: string, callback: (err: Error, body: any, statusCode: number) => void): any;
}
export interface ITestsRecommendationResponse {
    excludedTests: IExcludedTest[];
    recommendationSetStatus: RecommendationSetStatus;
    testSelectionEnabled: boolean;
}
export interface IExcludedTest {
    name: string;
    universalTestId: string;
    testFramework: string;
}
export declare enum RecommendedTestReason {
    PINNED = "pinned",
    IMPACTED = "impacted",
    FAILED = "failed"
}
export declare enum RecommendationSetStatus {
    NOT_READY = "notReady",
    READY = "ready",
    NO_HISTORY = "noHistory",
    ERROR = "error"
}
export interface IBuildEndData {
    appName: string;
    build: string;
    branch: string;
    status: IBuildEndStatus;
}
export interface IBuildEndStatus {
    success: boolean;
}
